"""
        Python bindings for MRC Segments
        -------------------------------
        .. currentmodule:: segment
        .. autosummary::
           :toctree: _generate
    """
from __future__ import annotations
import mrc.core.segment
import typing
import mrc.core.common
import mrc.core.subscriber

__all__ = [
    "Builder",
    "LaunchOptions",
    "MirrorTap",
    "ModuleRegistry",
    "Segment",
    "SegmentModule",
    "SegmentObject"
]


class Builder():
    def get_current_module_config(self) -> dict: ...
    def get_egress(self, name: str) -> SegmentObject: ...
    def get_ingress(self, name: str) -> SegmentObject: ...
    def init_module(self, module: SegmentModule) -> None: ...
    def load_module(self, module_id: str, registry_namespace: str, module_name: str, module_config: dict) -> SegmentModule: ...
    @typing.overload
    def make_edge(self, arg0: SegmentObject, arg1: SegmentObject) -> None: ...
    @typing.overload
    def make_edge(self, source: SegmentObject, sink: SegmentObject) -> None: ...
    @typing.overload
    def make_node(self, arg0: str, *args) -> SegmentObject: ...
    @typing.overload
    def make_node(self, arg0: str, arg1: typing.Callable[[object], object]) -> SegmentObject: ...
    def make_node_component(self, arg0: str, *args) -> SegmentObject: ...
    def make_node_full(self, arg0: str, arg1: typing.Callable[[mrc.core.subscriber.Observable, mrc.core.subscriber.Subscriber], None]) -> SegmentObject: ...
    def make_sink(self, name: str, on_next: typing.Callable[[object], None] = None, on_error: typing.Callable[[BaseException], None] = None, on_complete: typing.Callable[[], None] = None) -> SegmentObject: ...
    def make_sink_component(self, name: str, on_next: typing.Callable[[object], None] = None, on_error: typing.Callable[[BaseException], None] = None, on_complete: typing.Callable[[], None] = None) -> SegmentObject: ...
    @typing.overload
    def make_source(self, arg0: str, arg1: function) -> SegmentObject: ...
    @typing.overload
    def make_source(self, arg0: str, arg1: typing.Iterable) -> SegmentObject: ...
    @typing.overload
    def make_source(self, arg0: str, arg1: typing.Iterator) -> SegmentObject: ...
    @typing.overload
    def make_source_component(self, arg0: str, arg1: function) -> SegmentObject: ...
    @typing.overload
    def make_source_component(self, arg0: str, arg1: typing.Iterable) -> SegmentObject: ...
    @typing.overload
    def make_source_component(self, arg0: str, arg1: typing.Iterator) -> SegmentObject: ...
    def register_module_input(self, input_name: str, object: SegmentObject) -> None: ...
    def register_module_output(self, output_name: str, object: SegmentObject) -> None: ...
    def splice_edge(self, source: str, sink: str, splice_input: SegmentObject, splice_output: SegmentObject) -> None: ...
    pass
class LaunchOptions():
    @property
    def engine_factory_name(self) -> str:
        """
        :type: str
        """
    @engine_factory_name.setter
    def engine_factory_name(self, arg0: str) -> None:
        pass
    @property
    def engines_per_pe(self) -> int:
        """
        :type: int
        """
    @engines_per_pe.setter
    def engines_per_pe(self, arg0: int) -> None:
        pass
    @property
    def pe_count(self) -> int:
        """
        :type: int
        """
    @pe_count.setter
    def pe_count(self, arg0: int) -> None:
        pass
    pass
class MirrorTap():
    @typing.overload
    def __init__(self, arg0: str) -> None: ...
    @typing.overload
    def __init__(self, arg0: str, arg1: dict) -> None: ...
    def create_or_extend_egress_ports(self, egress_ports: list) -> list: ...
    def create_or_extend_ingress_ports(self, ingress_ports: list) -> list: ...
    def get_egress_tap_name(self) -> str: ...
    def get_ingress_tap_name(self) -> str: ...
    def stream_to(self, initializer: typing.Callable[[Builder], None], stream_to: str) -> typing.Callable[[Builder], None]: ...
    def tap(self, initializer: typing.Callable[[Builder], None], tap_from: str, tap_to: str) -> typing.Callable[[Builder], None]: ...
    pass
class ModuleRegistry():
    @staticmethod
    def contains(name: str, registry_namespace: str) -> bool: ...
    @staticmethod
    def contains_namespace(registry_namespace: str) -> bool: ...
    @staticmethod
    def get_module_constructor(name: str, registry_namespace: str) -> cpp_function: ...
    @staticmethod
    def is_version_compatible(release_version: typing.List[int]) -> bool: ...
    @staticmethod
    @typing.overload
    def register_module(name: str, registry_namespace: str, release_version: typing.List[int], fn_constructor: typing.Callable[[Builder], None]) -> None: ...
    @staticmethod
    @typing.overload
    def register_module(name: str, release_version: typing.List[int], fn_constructor: typing.Callable[[Builder], None]) -> None: ...
    @staticmethod
    def registered_modules() -> typing.Dict[str, typing.List[str]]: ...
    @staticmethod
    def unregister_module(name: str, registry_namespace: str, optional: bool = True) -> None: ...
    pass
class Segment():
    pass
class SegmentModule():
    def __init__(self, arg0: str) -> None: ...
    def component_prefix(self) -> str: ...
    def config(self) -> dict: ...
    def input_ids(self) -> typing.List[str]: ...
    def input_port(self, input_id: str) -> SegmentObject: ...
    def input_ports(self) -> typing.Dict[str, SegmentObject]: ...
    def module_type_name(self) -> str: ...
    def name(self) -> str: ...
    def output_ids(self) -> typing.List[str]: ...
    def output_port(self, output_id: str) -> SegmentObject: ...
    def output_ports(self) -> typing.Dict[str, SegmentObject]: ...
    pass
class SegmentObject():
    @property
    def launch_options(self) -> LaunchOptions:
        """
        :type: LaunchOptions
        """
    @property
    def name(self) -> str:
        """
        :type: str
        """
    pass
__version__ = '23.11.0'
